# 2022-12-05 - veBoost V2

Deployment of the veBoostV2, a replacement for the [`PreseededVotingEscrowDelegation`](../20220530-preseeded-voting-escrow-delegation). This simplifies the boost contract greatly and allows integration with [Paladin's](https://paladin.vote/) boost market.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`VeBoostV2` artifact](./artifact/VeBoostV2.json)